## Tangent 0.3 Math Formula Search Engine##

*First Released August 2015*

*Authors:*

**Kenny Davila and Richard Zanibbi**,
Rochester Institute of Technology, USA

**Andrew Kane and Frank Tompa**,
University of Waterloo, Canada

-----

Tangent 0.3 is an application designed for indexing and retrieval of math formulas from large collections of documents or web pages. A complete description of our system may be found in our technical report:

[Tangent 0.3 arXiv preprint](http://arxiv.org/abs/1507.06235)



##License##
	LICENSE: Source code, data and results are being released under a Non-Commercial Creative Commons License (see the LICENSE file). 


**Please cite the paper above if you use the source code or data in this repository, and indicate any changes made when code or data are re-released.**


##Package Overview##

This package contains the raw files corresponding to the results reported for human evaluation in our paper submitted to WSDM 2016. The human evaluation package contains the following directories:

+ **human_evaluation** <br /> 
  Set of results from human evaluation. The *human evaluation* experiments measure the perceived relevance of the results produced by our system under different conditions.   

+ **formula-highlighting** <br />
  Contains examples of our final search results for a few queries. The provided examples are arXiv documents organized by query and show how the system highlights the matched formulas on each document.


##Package Contents##

###Directory: human_evaluation###

A sample of 10 queries from the NTCIR-11 Wikipedia Task where selected for human evaluation of relevance of the results produced by our system. The relevance of each formula in the Top-10 results of 3 different conditions (No EOL pairs and W={1, 2, All}) was evaluated by humans using Likert Scale. The experiment had a total of 21 participants and their demographic data is also provided here. The human\_evaluation directory contains the following data:

+ **sample\_html** <br />
  The directory includes the HTML results for the queries selected for the human evaluation process. HTML results are provided for both Datasets, Wikipedia and arXiv, using one separate sub-directory per Dataset. Then, a set of directories is included to show HTML results per condition. A naming convention has been adopted to identify the system conditions used to generate each set of results. If the directory begins with the prefix "EOL" it means that the EOL pairs were active in the core engine. In addition, all directory names contain the sequence w\_{window\_size}. For each condition, a set of directories with HTML results per query is provided, and these directories are named query\_{query_number}. Each query directory contains 3 HTML files and a sub-directory containing all images used by these 3 files. The HTML files provided per query are:

  + **{query\_name}\_main.html:** Main results file which shows the matching formulas grouped by similar score and same structural matching. Diagrams of substructures that have been matched are provided for each structural group (click on the 'Graphs' button to see these).   
  + **{query\_name}\_docs.html:** Shows the final ranking of documents, considering that each document might contain multiple unique formula matches.
  + **{query\_name}_formulas.html** Extended version of the ranking per formula which shows the complete list of documents that contain each individual formulas. <br />
  
  + The HTML pages contain links which make possible to navigate from each view to any of the other two. *The pages also provide links to the visualization tool which highlights the matched formulas in their original documents. However, These links are broken and will not work under the current directory structure.
  Instead, some example formula-highlighting results are provided in a separate directory called **formula-highlighting**.*


+ **compiled\_results.csv** <br />
  A complete set of human evaluation ratings for each individual result of each of the selected queries. A total of 6,300 ratings are included in this file (10  queries * 3 conditions * 10 results per query per condition * 21 participants). In general, a total of 300 relevance ratings are listed per participant, but many formulas appear in multiple conditions for the same query and in those cases the participants were required to rate the formula only once. All ratings are given in Likert scale where 5 represents the rating 'Very Similar' and 1 represents 'Very Dissimilar.' 

+ **average\_ratings.csv** <br />
  Contains a summary of the average ratings given to each unique candidate for each query. 

+ **wiki\_human\_nDCG.csv** <br />
  Normalized Discounted Gain (nDCG) values for each of the 3 conditions tested in our human experiments. The ideal top-10 results are computed using the average likert ratings of each candidate of each query, and their relevance values are used to normalize the DCG values of each query for each condition.   

+ **Demographics.xlsx** <br />
  A spreadsheet containing the demographic information and comments provided by the participants of our human evaluation experiment.


###Directory: formula-highlighting###

After running a query, our system produces HTML output to show the final search results including links to the original documents were the formulas were found. However, even after finding the document which contains the formula, it might be difficult for the final user to locate the formula on the given document. For this reason, Tangent provides highlighting functionality which places colored boxes around the matched formulas in a given document  making the process of locating the formula in the document much easier for the final users. Some examples of this functionality are provided in this folder. Currently the highlighting method works better on arXiv document like the examples provided. The arXiv directory contains a set of sub-directories, one per query, containing some examples of highlighted documents for the top-2 documents per query.

The javascript code used to produce these is available at **formula-highlighting/highlighter.html**. To use highlighter.html, you can open it in a web-browser, and add the following url parameters:

+ doc: Provide the relative url of the document where formulas will be highlighted
+ exp: Use this parameter to specify the offset of a formula that you want to be highlighted in the document doc.
+ int: A value between 0.0 and 1.0 that indicates the intensity of the highlighting where 0.0 corresponds to a very thin black border while 1.0 corresponds to a very thick red border.

Note that multiple formulas can be highlighted on a given document. To achieve this simply repeat the pair of parameters *exp* and *int* for every formula that you want to highlight. For example: 

	highlighter.html?doc=test_document.xhtml&exp=14&int=1.0&exp=16&int=0.47

Will load the document called *test_document.xhtml*, and it will highlight the formula with offset 14 with intensity of 1.0 and the formula with offset 16 with intensity of 0.47. In our system, these intensities values are directly proportional to the MSS scores of the matching formulas.